/*=========================================================================

  Program:   Visualization Toolkit
  Module:    $RCSfile: vtkMoveableMeshSource.h,v $

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkMoveableMeshSource - create a line defined by two end points
// .SECTION Description
// vtkMoveableMeshSource is a source object that creates a polyline defined by
// two endpoints. The number of segments composing the polyline is
// controlled by setting the object resolution.

#ifndef __vtkMoveableMeshSource_h
#define __vtkMoveableMeshSource_h

#include "vtkPolyDataAlgorithm.h"

class VTK_GRAPHICS_EXPORT vtkMoveableMeshSource : public vtkPolyDataAlgorithm 
{
public:
  static vtkMoveableMeshSource *New();
  vtkTypeRevisionMacro(vtkMoveableMeshSource,vtkPolyDataAlgorithm);
  void PrintSelf(ostream& os, vtkIndent indent);

  // Description:
  // Set position of first end point.
  vtkSetVector3Macro(Point1,double);
  vtkGetVectorMacro(Point1,double,3);

  // Description:
  // Set position of other end point.
  vtkSetVector3Macro(Point2,double);
  vtkGetVectorMacro(Point2,double,3);

  // Description:
  // Divide line into resolution number of pieces.
  vtkSetClampMacro(Resolution,int,1,VTK_LARGE_INTEGER);
  vtkGetMacro(Resolution,int);

protected:
  vtkMoveableMeshSource(int res=1);
  ~vtkMoveableMeshSource() {};

  int RequestData(vtkInformation *, vtkInformationVector **, vtkInformationVector *);
  int RequestInformation(vtkInformation *, vtkInformationVector **, vtkInformationVector *);
  double Point1[3];
  double Point2[3];
  int Resolution;
private:
  vtkMoveableMeshSource(const vtkMoveableMeshSource&);  // Not implemented.
  void operator=(const vtkMoveableMeshSource&);  // Not implemented.
};

#endif
